@@ -5,12 +5,12 @@ Factories for SHAP explainers from the ``shap`` package.
 import functools
 import logging
 from abc import ABCMeta, abstractmethod
-from distutils import version
-from typing import Any, Dict, Mapping, Optional
+from typing import Any, Dict, Mapping, Optional, Union
 
+import numpy as np
 import pandas as pd
 import shap
-from shap.explainers.explainer import Explainer
+from packaging import version
 from sklearn.base import BaseEstimator
 
 from pytools.api import AllTracker, inheritdoc, validate_type
@@ -18,20 +18,48 @@ from sklearndf import ClassifierDF, LearnerDF, RegressorDF
 
 log = logging.getLogger(__name__)
 
-__all__ = ["ExplainerFactory", "TreeExplainerFactory", "KernelExplainerFactory"]
+__all__ = [
+    "BaseExplainer",
+    "ExplainerFactory",
+    "KernelExplainerFactory",
+    "TreeExplainerFactory",
+]
+
+__shap_version__ = version.parse(shap.__version__)
+__shap_earliest_supported__ = version.parse("0.34")
+__shap_0_36__ = version.parse("0.36")
+__shap_not_yet_supported__ = version.parse("0.39")
+
 
 #
 # Ensure we have a supported version of the shap package
 #
 
-_SHAP_EARLIEST_VERSION = version.LooseVersion("0.34")
-
-if version.LooseVersion(shap.__version__) < _SHAP_EARLIEST_VERSION:
-    raise RuntimeError(
-        f"shap package version {shap.__version__} is not supported; "
-        f"please upgrade to version {_SHAP_EARLIEST_VERSION} or later"
+if (
+    __shap_version__ < __shap_earliest_supported__
+    or __shap_version__ >= __shap_not_yet_supported__
+):
+    log.warning(
+        f"shap package v{__shap_version__} is not supported; "
+        f"current support includes versions starting at v{__shap_earliest_supported__} "
+        f"and preceding v{__shap_not_yet_supported__}"
     )
 
+#
+# conditional and mock imports
+#
+
+if __shap_version__ < __shap_0_36__:
+    # noinspection PyUnresolvedReferences
+    from shap.explainers.explainer import Explainer
+else:
+    try:
+        # noinspection PyUnresolvedReferences
+        from shap import Explainer
+    except ImportError as e:
+        log.warning(e)
+        Explainer = type("Explainer", (), {})
+
 #
 # Ensure all symbols introduced below are included in __all__
 #
@@ -44,6 +72,50 @@ __tracker = AllTracker(globals())
 #
 
 
+class BaseExplainer(metaclass=ABCMeta):
+    """
+    Abstract base class of SHAP explainers, providing stubs for methods used by FACET
+    but not consistently supported by class :class:`shap.Explainer` across different
+    versions of the `shap` package.
+    """
+
+    # noinspection PyPep8Naming,PyUnresolvedReferences
+    @abstractmethod
+    def shap_values(
+        self,
+        X: Union[np.ndarray, pd.DataFrame, "catboost.Pool"],  # noqa: F821
+        y: Union[None, np.ndarray, pd.Series] = None,
+        **kwargs,
+    ) -> np.ndarray:
+        """
+        Estimate the SHAP values for a set of samples.
+
+        :param X: matrix of samples (# samples x # features) on which to explain the
+            model's output
+        :param y: array of label values for each sample, used when explaining loss
+            functions
+        """
+        pass
+
+    # noinspection PyPep8Naming,PyUnresolvedReferences
+    @abstractmethod
+    def shap_interaction_values(
+        self,
+        X: Union[np.ndarray, pd.DataFrame, "catboost.Pool"],  # noqa: F821
+        y: Union[None, np.ndarray, pd.Series] = None,
+        **kwargs,
+    ) -> np.ndarray:
+        """
+        Estimate the SHAP interaction values for a set of samples.
+
+        :param X: matrix of samples (# samples x # features) on which to explain the
+            model's output
+        :param y: array of label values for each sample, used when explaining loss
+            functions
+        """
+        pass
+
+
 class ExplainerFactory(metaclass=ABCMeta):
     """
     A factory for constructing :class:`~shap.Explainer` objects.
@@ -76,7 +148,7 @@ class ExplainerFactory(metaclass=ABCMeta):
     @abstractmethod
     def make_explainer(
         self, model: LearnerDF, data: Optional[pd.DataFrame]
-    ) -> Explainer:
+    ) -> BaseExplainer:
         """
         Construct a new :class:`~shap.Explainer` to compute shap values.
 
@@ -97,6 +169,9 @@ class ExplainerFactory(metaclass=ABCMeta):
             )
 
 
+_TreeExplainer: Optional[type] = None
+
+
 @inheritdoc(match="[see superclass]")
 class TreeExplainerFactory(ExplainerFactory):
     """
@@ -131,6 +206,13 @@ class TreeExplainerFactory(ExplainerFactory):
         self.feature_perturbation = feature_perturbation
         self._uses_background_dataset = use_background_dataset
 
+        global _TreeExplainer
+
+        if _TreeExplainer is None:
+            _TreeExplainer = type(
+                "_TreeExplainer", (shap.TreeExplainer, BaseExplainer), {}
+            )
+
     @property
     def explains_raw_output(self) -> bool:
         """[see superclass]"""
@@ -153,7 +235,7 @@ class TreeExplainerFactory(ExplainerFactory):
 
         self._validate_background_dataset(data=data)
 
-        explainer = shap.TreeExplainer(
+        explainer = _TreeExplainer(
             model=model.native_estimator,
             data=data if self._uses_background_dataset else None,
             **self._remove_null_kwargs(
@@ -171,6 +253,22 @@ class TreeExplainerFactory(ExplainerFactory):
         return explainer
 
 
+class _KernelExplainer(shap.KernelExplainer, BaseExplainer):
+    # noinspection PyPep8Naming,PyUnresolvedReferences
+    def shap_interaction_values(
+        self,
+        X: Union[np.ndarray, pd.DataFrame, "catboost.Pool"],  # noqa: F821
+        y: Union[None, np.ndarray, pd.Series] = None,
+        **kwargs,
+    ) -> np.ndarray:
+        """
+        Not implemented.
+        """
+        raise NotImplementedError()
+
+    pass
+
+
 @inheritdoc(match="[see superclass]")
 class KernelExplainerFactory(ExplainerFactory):
     """
@@ -245,7 +343,7 @@ class KernelExplainerFactory(ExplainerFactory):
         if data_size_limit is not None and len(data) > data_size_limit:
             data = shap.kmeans(data, data_size_limit, round_values=True)
 
-        explainer = shap.KernelExplainer(
+        explainer = _KernelExplainer(
             model=model_fn, data=data, **self._remove_null_kwargs(dict(link=self.link))
         )
 
